@@ -188,12 +188,18 @@ INVALIDPARAMETER_INVALIDCHANNEL = 'InvalidParameter.InvalidChannel'
 # id类型参数不合法，请检查后重试。
 INVALIDPARAMETER_INVALIDID = 'InvalidParameter.InvalidId'
 
+# 参数Limit不正确。
+INVALIDPARAMETER_INVALIDLIMIT = 'InvalidParameter.InvalidLimit'
+
 # 手机号码不正确。
 INVALIDPARAMETER_INVALIDMOBILE = 'InvalidParameter.InvalidMobile'
 
 # 姓名不正确。
 INVALIDPARAMETER_INVALIDNAME = 'InvalidParameter.InvalidName'
 
+# 参数Offset不正确。
+INVALIDPARAMETER_INVALIDOFFSET = 'InvalidParameter.InvalidOffset'
+
 # OpenId不正确。
 INVALIDPARAMETER_INVALIDOPENID = 'InvalidParameter.InvalidOpenId'
 
@@ -218,6 +224,9 @@ INVALIDPARAMETER_INVALIDVERIFYCHANNEL = 'InvalidParameter.InvalidVerifyChannel'
 # 验证码不正确。
 INVALIDPARAMETER_INVALIDVERIFYCODE = 'InvalidParameter.InvalidVerifyCode'
 
+# 缺少必填控件的值。
+INVALIDPARAMETER_MISSINGREQUIREDCOMPONENTVALUE = 'InvalidParameter.MissingRequiredComponentValue'
+
 # 不合法的手机号，请检查后重试。
 INVALIDPARAMETER_MOBILE = 'InvalidParameter.Mobile'
 
@@ -356,6 +365,9 @@ OPERATIONDENIED_CCUSERREPEAT = 'OperationDenied.CcUserRepeat'
 # 电子文档不可用，请稍后重试。
 OPERATIONDENIED_DOCUMENTNOAVAILABLE = 'OperationDenied.DocumentNoAvailable'
 
+# 此企业无该资源使用权限。
+OPERATIONDENIED_ERRNORESOURCEACCESS = 'OperationDenied.ErrNoResourceAccess'
+
 # 个人签署方不支持设置企业名称，请确认签署人类型后重试。
 OPERATIONDENIED_ERRNOSUPPORTINDIVIDUALHASORGANIZATIONNAME = 'OperationDenied.ErrNoSupportIndividualHasOrganizationName'
 
