@@ -37,7 +37,7 @@ class AgentAuditedClient(AbstractModel):
         :type ClientRemark: str
         :param ClientName: 代客名称（首选实名认证名称）
         :type ClientName: str
-        :param AuthType: 认证类型, 0：个人，1：企业；其他：未认证
+        :param AuthType: 认证类型, 0：个人，1：企业；其他：未认证或无效值
         :type AuthType: str
         :param AppId: 代客APPID
         :type AppId: str
@@ -749,6 +749,7 @@ class AuditApplyClientResponse(AbstractModel):
         :param AuditResult: 审核结果，包括accept/reject/qcloudaudit（腾讯云审核）
         :type AuditResult: str
         :param AgentTime: 关联时间对应的时间戳
+注意：此字段可能返回 null，表示取不到有效值。
         :type AgentTime: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -890,7 +891,7 @@ class DescribeAgentAuditedClientsRequest(AbstractModel):
         :type Offset: int
         :param Limit: 限制数目
         :type Limit: int
-        :param ClientType: 客户类型：可以为new(新拓)/assign(指定)/old(存量已关联)/old_newchecking(存量-新关联考核中)/old_newnotpass(存量-新关联未达标)/direct(直销)/direct_newopp(直销(新商机))/空
+        :param ClientType: 可以为new(自拓)/assign(指派)/old(官网)/direct(直销)/direct_newopp(直销(新商机))/空
         :type ClientType: str
         :param ProjectType: 项目类型：可以为self(自拓项目)/platform(合作项目)/repeat(复算项目  )/空
         :type ProjectType: str
@@ -1193,11 +1194,11 @@ class DescribeAgentDealsByCacheRequest(AbstractModel):
         r"""
         :param Offset: 偏移量
         :type Offset: int
-        :param Limit: 限制数目
+        :param Limit: 限制数目 最大200
         :type Limit: int
-        :param CreatTimeRangeStart: 下单时间范围起始点
+        :param CreatTimeRangeStart: 下单时间范围起始点【请保持时间范围最大90天】
         :type CreatTimeRangeStart: str
-        :param CreatTimeRangeEnd: 下单时间范围终止点
+        :param CreatTimeRangeEnd: 下单时间范围终止点【请保持时间范围最大90天】
         :type CreatTimeRangeEnd: str
         :param Order: 0:下单时间降序；其他：下单时间升序
         :type Order: int
@@ -1205,8 +1206,10 @@ class DescribeAgentDealsByCacheRequest(AbstractModel):
         :type Status: int
         :param OwnerUins: 下单人账号ID列表
         :type OwnerUins: list of str
-        :param DealNames: 订单号列表
+        :param DealNames: 子订单号列表
         :type DealNames: list of str
+        :param BigDealIds: 大订单号列表
+        :type BigDealIds: list of str
         :param PayerMode: 支付方式，0：自付；1：代付
         :type PayerMode: int
         """
@@ -1218,6 +1221,7 @@ class DescribeAgentDealsByCacheRequest(AbstractModel):
         self.Status = None
         self.OwnerUins = None
         self.DealNames = None
+        self.BigDealIds = None
         self.PayerMode = None
 
 
@@ -1230,6 +1234,7 @@ class DescribeAgentDealsByCacheRequest(AbstractModel):
         self.Status = params.get("Status")
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
+        self.BigDealIds = params.get("BigDealIds")
         self.PayerMode = params.get("PayerMode")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
@@ -1279,11 +1284,11 @@ class DescribeAgentDealsCacheRequest(AbstractModel):
         r"""
         :param Offset: 偏移量
         :type Offset: int
-        :param Limit: 限制数目
+        :param Limit: 限制数目 最大200
         :type Limit: int
-        :param CreatTimeRangeStart: 下单时间范围起始点
+        :param CreatTimeRangeStart: 下单时间范围起始点【请保持时间范围最大90天】
         :type CreatTimeRangeStart: str
-        :param CreatTimeRangeEnd: 下单时间范围终止点
+        :param CreatTimeRangeEnd: 下单时间范围终止点【请保持时间范围最大90天】
         :type CreatTimeRangeEnd: str
         :param Order: 0:下单时间降序；其他：下单时间升序
         :type Order: int
@@ -1365,7 +1370,7 @@ class DescribeAgentPayDealsRequest(AbstractModel):
         r"""
         :param Offset: 偏移量
         :type Offset: int
-        :param Limit: 限制数目
+        :param Limit: 限制数目 最大100
         :type Limit: int
         :param CreatTimeRangeStart: 下单时间范围起始点(不传时会默认查15天内订单，传值时需要传15天内的起始时间)
         :type CreatTimeRangeStart: str
@@ -1447,7 +1452,7 @@ class DescribeAgentPayDealsV2Request(AbstractModel):
         r"""
         :param Offset: 偏移量
         :type Offset: int
-        :param Limit: 限制数目
+        :param Limit: 限制数目 最大100
         :type Limit: int
         :param CreatTimeRangeStart: 下单时间范围起始点(不传时会默认查15天内订单，传值时需要传15天内的起始时间)
         :type CreatTimeRangeStart: str
@@ -1459,8 +1464,10 @@ class DescribeAgentPayDealsV2Request(AbstractModel):
         :type Status: int
         :param OwnerUins: 下单人账号ID列表
         :type OwnerUins: list of str
-        :param DealNames: 订单号列表
+        :param DealNames: 子订单号列表
         :type DealNames: list of str
+        :param BigDealIds: 大订单号列表
+        :type BigDealIds: list of str
         """
         self.Offset = None
         self.Limit = None
@@ -1470,6 +1477,7 @@ class DescribeAgentPayDealsV2Request(AbstractModel):
         self.Status = None
         self.OwnerUins = None
         self.DealNames = None
+        self.BigDealIds = None
 
 
     def _deserialize(self, params):
@@ -1481,6 +1489,7 @@ class DescribeAgentPayDealsV2Request(AbstractModel):
         self.Status = params.get("Status")
         self.OwnerUins = params.get("OwnerUins")
         self.DealNames = params.get("DealNames")
+        self.BigDealIds = params.get("BigDealIds")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1531,7 +1540,7 @@ class DescribeAgentSelfPayDealsRequest(AbstractModel):
         :type OwnerUin: str
         :param Offset: 偏移量
         :type Offset: int
-        :param Limit: 限制数目
+        :param Limit: 限制数目 最大100
         :type Limit: int
         :param CreatTimeRangeStart: 下单时间范围起始点(不传时会默认查15天内订单，传值时需要传15天内的起始时间)
         :type CreatTimeRangeStart: str
@@ -1613,7 +1622,7 @@ class DescribeAgentSelfPayDealsV2Request(AbstractModel):
         :type OwnerUin: str
         :param Offset: 偏移量
         :type Offset: int
-        :param Limit: 限制数目
+        :param Limit: 限制数目 最大100
         :type Limit: int
         :param CreatTimeRangeStart: 下单时间范围起始点(不传时会默认查15天内订单，传值时需要传15天内的起始时间)
         :type CreatTimeRangeStart: str
@@ -1623,8 +1632,10 @@ class DescribeAgentSelfPayDealsV2Request(AbstractModel):
         :type Order: int
         :param Status: 订单的状态(1：未支付;2：已支付;3：发货中;4：已发货;5：发货失败;6：已退款;7：已关单;8：订单过期;9：订单已失效;10：产品已失效;11：代付拒绝;12：支付中)
         :type Status: int
-        :param DealNames: 订单号列表
+        :param DealNames: 子订单号列表
         :type DealNames: list of str
+        :param BigDealIds: 大订单号列表
+        :type BigDealIds: list of str
         """
         self.OwnerUin = None
         self.Offset = None
@@ -1634,6 +1645,7 @@ class DescribeAgentSelfPayDealsV2Request(AbstractModel):
         self.Order = None
         self.Status = None
         self.DealNames = None
+        self.BigDealIds = None
 
 
     def _deserialize(self, params):
@@ -1645,6 +1657,7 @@ class DescribeAgentSelfPayDealsV2Request(AbstractModel):
         self.Order = params.get("Order")
         self.Status = params.get("Status")
         self.DealNames = params.get("DealNames")
+        self.BigDealIds = params.get("BigDealIds")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1764,7 +1777,7 @@ class DescribeClientBalanceResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Balance: 账户可用余额，单位分 （可用余额 = 现金余额 - 冻结金额）
+        :param Balance: 账户可用余额，单位分 （可用余额 = 现金余额 - 冻结金额）  【注：该数据准确性存疑，请切换至DescribeClientBalanceNew取值】
         :type Balance: int
         :param Cash: 账户现金余额，单位分
         :type Cash: int
@@ -1782,6 +1795,68 @@ class DescribeClientBalanceResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeRebateInfosNewRequest(AbstractModel):
+    """DescribeRebateInfosNew请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RebateMonth: 返佣月份，如2018-02
+        :type RebateMonth: str
+        :param Offset: 偏移量
+        :type Offset: int
+        :param Limit: 限制数目
+        :type Limit: int
+        """
+        self.RebateMonth = None
+        self.Offset = None
+        self.Limit = None
+
+
+    def _deserialize(self, params):
+        self.RebateMonth = params.get("RebateMonth")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeRebateInfosNewResponse(AbstractModel):
+    """DescribeRebateInfosNew返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RebateInfoSet: 返佣信息列表
+        :type RebateInfoSet: list of RebateInfoElemNew
+        :param TotalCount: 符合查询条件返佣信息数目
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RebateInfoSet = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("RebateInfoSet") is not None:
+            self.RebateInfoSet = []
+            for item in params.get("RebateInfoSet"):
+                obj = RebateInfoElemNew()
+                obj._deserialize(item)
+                self.RebateInfoSet.append(obj)
+        self.TotalCount = params.get("TotalCount")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeRebateInfosRequest(AbstractModel):
     """DescribeRebateInfos请求参数结构体
 
@@ -2109,6 +2184,50 @@ class RebateInfoElem(AbstractModel):
         
 
 
+class RebateInfoElemNew(AbstractModel):
+    """返佣信息定义
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Uin: 代理商账号ID
+        :type Uin: str
+        :param RebateMonth: 返佣月份，如2018-02
+        :type RebateMonth: str
+        :param Amt: 返佣金额，单位分
+        :type Amt: int
+        :param MonthSales: 月度业绩，单位分
+        :type MonthSales: int
+        :param QuarterSales: 季度业绩，单位分
+        :type QuarterSales: int
+        :param ExceptionFlag: NORMAL(正常)/HAS_OVERDUE_BILL(欠费)/NO_CONTRACT(缺合同)
+        :type ExceptionFlag: str
+        """
+        self.Uin = None
+        self.RebateMonth = None
+        self.Amt = None
+        self.MonthSales = None
+        self.QuarterSales = None
+        self.ExceptionFlag = None
+
+
+    def _deserialize(self, params):
+        self.Uin = params.get("Uin")
+        self.RebateMonth = params.get("RebateMonth")
+        self.Amt = params.get("Amt")
+        self.MonthSales = params.get("MonthSales")
+        self.QuarterSales = params.get("QuarterSales")
+        self.ExceptionFlag = params.get("ExceptionFlag")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class RemovePayRelationForClientRequest(AbstractModel):
     """RemovePayRelationForClient请求参数结构体
 
