@@ -58,13 +58,13 @@ class TiiaClient(AbstractClient):
 
 
     def CreateGroup(self, request):
-        """用于创建一个空的图片库，如果图片库已存在则返回错误。不同类型图库对应不同的图像搜索服务，根据输入参数GroupType区分。
+        """本接口用于创建一个空的图片库，图片库主要用于存储在创建图片时提取的图片特征数据，如果图片库已存在则返回错误。不同的图片库类型对应不同的图像搜索服务类型，根据输入参数GroupType区分。
 
-        | 服务类型 | GroupType参数值 |功能描述 |
-        |  :------  | :----- |:-----------------  |
-        | 相同图像搜索<img width=30/>    | 4 |在自建图库中搜索相同原图，可支持裁剪、翻转、调色、加水印后的图片搜索，适用于图片版权保护、原图查询等场景。|
-        | 商品图像搜索<img width=30/>   | 5 |在自建图库中搜索相同或相似的商品图片，适用于商品分类、检索、推荐等电商场景。|
-        | 相似图像搜索<img width=30/>   | 6 |在自建图片库中搜索与输入图片高度相似的图片，适用于相似图案、logo、纹理等图像元素的搜索。|
+        | 服务类型 | GroupType入参 |功能描述 |
+        |  :----------  | :----- |:-----------------  |
+        | 相同图像搜索<div style="width: 70pt"> | 4 |在自建图片库中搜索相同原图或高相似图，并给出相似度打分，可支持裁剪、翻转、调色、加水印等二次编辑后的图片搜索。适用于图片版权保护、原图查询等场景。|
+        | 商品图像搜索<div style="width: 70pt"> | 5 |在自建图库中搜索同款商品，并给出相似度打分。对于服饰类商品可支持识别服饰类别、属性等信息。适用于商品分类、检索、推荐等电商场景。|
+        | 相似图像搜索<div style="width: 70pt"> | 6 |在自建图库中搜索相似的图案、logo、纹理等图像元素或主体，并给出相似度打分。|
 
         :param request: Request instance for CreateGroup.
         :type request: :class:`tencentcloud.tiia.v20190529.models.CreateGroupRequest`
@@ -93,7 +93,7 @@ class TiiaClient(AbstractClient):
 
 
     def CreateImage(self, request):
-        """创建图片，并添加对应图片的自定义信息。
+        """创建图片，并添加对应图片的自定义信息。模型将在创建图片时自动提取图像特征并存储到指定的图片库中。
 
         :param request: Request instance for CreateImage.
         :type request: :class:`tencentcloud.tiia.v20190529.models.CreateImageRequest`
@@ -522,7 +522,10 @@ class TiiaClient(AbstractClient):
 
 
     def EnhanceImage(self, request):
-        """传入一张图片，输出清晰度提升后的图片。
+        """>!
+        - 图像清晰度增强接口将于2022年8月31日结束免费公测，2022年9月1日起正式转入计费。若您不需要使用本服务，请及时停止使用。价格详情在[计费概述](https://cloud.tencent.com/document/product/865/17627)中提前公示，请您参阅。
+
+        传入一张图片，输出清晰度提升后的图片。
 
         可以消除图片有损压缩导致的噪声，和使用滤镜、拍摄失焦导致的模糊。让图片的边缘和细节更加清晰自然。
         >
@@ -619,7 +622,7 @@ class TiiaClient(AbstractClient):
 
 
     def SearchImage(self, request):
-        """本接口用于对一张待识别的商品图片，在指定图片库中检索出最相似的图片列表。
+        """本接口用于对一张图片，在指定图片库中检索出与之相似的图片列表。
 
         :param request: Request instance for SearchImage.
         :type request: :class:`tencentcloud.tiia.v20190529.models.SearchImageRequest`
